@@ -2,7 +2,7 @@
 // SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "globalshortcutfilter.h"
-#include "src/core/controller.h"
+#include "src/core/flameshot.h"
 #include <qt_windows.h>
 
 GlobalShortcutFilter::GlobalShortcutFilter(QObject* parent)
@@ -20,7 +20,7 @@ GlobalShortcutFilter::GlobalShortcutFilter(QObject* parent)
 
 bool GlobalShortcutFilter::nativeEventFilter(const QByteArray& eventType,
                                              void* message,
-                                             long* result)
+                                             qintptr* result)
 {
     Q_UNUSED(eventType)
     Q_UNUSED(result)
@@ -31,15 +31,15 @@ bool GlobalShortcutFilter::nativeEventFilter(const QByteArray& eventType,
         // support would need custom shortcuts defined by the user.
         const quint32 keycode = HIWORD(msg->lParam);
         const quint32 modifiers = LOWORD(msg->lParam);
-
+#ifdef ENABLE_IMGUR
         // Show screenshots history
         if (VK_SNAPSHOT == keycode && MOD_SHIFT == modifiers) {
-            Controller::getInstance()->showRecentScreenshots();
+            Flameshot::instance()->history();
         }
-
+#endif
         // Capture screen
         if (VK_SNAPSHOT == keycode && 0 == modifiers) {
-            Controller::getInstance()->requestCapture(
+            Flameshot::instance()->requestCapture(
               CaptureRequest(CaptureRequest::GRAPHICAL_MODE));
         }
 
