@@ -22,9 +22,9 @@ QString RectangleTool::name() const
     return tr("Rectangle");
 }
 
-ToolType RectangleTool::nameID() const
+CaptureTool::Type RectangleTool::type() const
 {
-    return ToolType::RECTANGLE;
+    return CaptureTool::TYPE_RECTANGLE;
 }
 
 QString RectangleTool::description() const
@@ -45,22 +45,22 @@ void RectangleTool::process(QPainter& painter, const QPixmap& pixmap)
     QPen orig_pen = painter.pen();
     QBrush orig_brush = painter.brush();
     painter.setPen(
-      QPen(color(), thickness(), Qt::SolidLine, Qt::SquareCap, Qt::RoundJoin));
+      QPen(color(), size(), Qt::SolidLine, Qt::SquareCap, Qt::RoundJoin));
     painter.setBrush(QBrush(color()));
-    if (thickness() == 0) {
+    if (size() == 0) {
         painter.drawRect(QRect(points().first, points().second));
     } else {
         QPainterPath path;
         int offset =
-          thickness() <= 1 ? 1 : static_cast<int>(round(thickness() / 2 + 0.5));
+          size() <= 1 ? 1 : static_cast<int>(round(size() / 2 + 0.5));
         path.addRoundedRect(
           QRectF(
             std::min(points().first.x(), points().second.x()) - offset,
             std::min(points().first.y(), points().second.y()) - offset,
             std::abs(points().first.x() - points().second.x()) + offset * 2,
             std::abs(points().first.y() - points().second.y()) + offset * 2),
-          thickness(),
-          thickness());
+          size(),
+          size());
         painter.fillPath(path, color());
     }
     painter.setPen(orig_pen);
@@ -70,10 +70,10 @@ void RectangleTool::process(QPainter& painter, const QPixmap& pixmap)
 void RectangleTool::drawStart(const CaptureContext& context)
 {
     AbstractTwoPointTool::drawStart(context);
-    thicknessChanged(context.thickness);
+    onSizeChanged(context.toolSize);
 }
 
-void RectangleTool::pressed(const CaptureContext& context)
+void RectangleTool::pressed(CaptureContext& context)
 {
     Q_UNUSED(context)
 }
