@@ -24,8 +24,13 @@ class AbstractLogger;
  * as it appears in the config file, `TYPE` is the C++ type. At the same time
  * `KEY` is the name of the generated getter function.
  */
+// clang-format off
 #define CONFIG_GETTER(KEY, TYPE)                                               \
-    TYPE KEY() { return value(QStringLiteral(#KEY)).value<TYPE>(); }
+    TYPE KEY()                                                                 \
+    {                                                                          \
+        return value(QStringLiteral(#KEY)).value<TYPE>();                      \
+    }
+// clang-format on
 
 /**
  * Declare and implement a setter for a config option. `FUNC` is the name of the
@@ -81,12 +86,21 @@ public:
     CONFIG_GETTER_SETTER(showDesktopNotification,
                          setShowDesktopNotification,
                          bool)
+    CONFIG_GETTER_SETTER(showAbortNotification, setShowAbortNotification, bool)
     CONFIG_GETTER_SETTER(filenamePattern, setFilenamePattern, QString)
     CONFIG_GETTER_SETTER(disabledTrayIcon, setDisabledTrayIcon, bool)
+    CONFIG_GETTER_SETTER(useGrimAdapter, useGrimAdapter, bool)
+    CONFIG_GETTER_SETTER(disabledGrimWarning, disabledGrimWarning, bool)
     CONFIG_GETTER_SETTER(drawThickness, setDrawThickness, int)
     CONFIG_GETTER_SETTER(drawFontSize, setDrawFontSize, int)
+    CONFIG_GETTER_SETTER(drawCircleCounterSize, setDrawCircleCounterSize, int)
+    CONFIG_GETTER_SETTER(drawPixelateSize, setDrawPixelateSize, int)
+    CONFIG_GETTER_SETTER(drawRectangleSize, setDrawRectangleSize, int)
+    CONFIG_GETTER_SETTER(drawMarkerSize, setDrawMarkerSize, int)
     CONFIG_GETTER_SETTER(keepOpenAppLauncher, setKeepOpenAppLauncher, bool)
+#if !defined(DISABLE_UPDATE_CHECKER)
     CONFIG_GETTER_SETTER(checkForUpdates, setCheckForUpdates, bool)
+#endif
     CONFIG_GETTER_SETTER(allowMultipleGuiInstances,
                          setAllowMultipleGuiInstances,
                          bool)
@@ -94,10 +108,9 @@ public:
     CONFIG_GETTER_SETTER(showStartupLaunchMessage,
                          setShowStartupLaunchMessage,
                          bool)
+    CONFIG_GETTER_SETTER(showQuitPrompt, setShowQuitPrompt, bool)
     CONFIG_GETTER_SETTER(contrastOpacity, setContrastOpacity, int)
-    CONFIG_GETTER_SETTER(copyAndCloseAfterUpload,
-                         setCopyAndCloseAfterUpload,
-                         bool)
+    CONFIG_GETTER_SETTER(copyURLAfterUpload, setCopyURLAfterUpload, bool)
     CONFIG_GETTER_SETTER(historyConfirmationToDelete,
                          setHistoryConfirmationToDelete,
                          bool)
@@ -120,6 +133,14 @@ public:
     CONFIG_GETTER_SETTER(copyOnDoubleClick, setCopyOnDoubleClick, bool)
     CONFIG_GETTER_SETTER(uploadClientSecret, setUploadClientSecret, QString)
     CONFIG_GETTER_SETTER(saveLastRegion, setSaveLastRegion, bool)
+    CONFIG_GETTER_SETTER(showSelectionGeometry, setShowSelectionGeometry, int)
+    CONFIG_GETTER_SETTER(jpegQuality, setJpegQuality, int)
+    CONFIG_GETTER_SETTER(reverseArrow, setReverseArrow, bool)
+    CONFIG_GETTER_SETTER(insecurePixelate, setInsecurePixelate, bool)
+    CONFIG_GETTER_SETTER(showSelectionGeometryHideTime,
+                         showSelectionGeometryHideTime,
+                         int)
+
     // SPECIAL CASES
     bool startupLaunch();
     void setStartupLaunch(const bool);
@@ -172,6 +193,6 @@ private:
     QSharedPointer<ValueHandler> valueHandler(const QString& key) const;
     void assertKeyRecognized(const QString& key) const;
     bool isShortcut(const QString& key) const;
-    QString baseName(QString key) const;
+    QString baseName(const QString& key) const;
     void cleanUnusedKeys(const QString& group, const QSet<QString>& keys) const;
 };
