@@ -1,23 +1,8 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "buttonhandler.h"
 #include "src/utils/globalvalues.h"
-#include <QGuiApplication>
 #include <QPoint>
 #include <QScreen>
 
@@ -40,8 +25,9 @@ ButtonHandler::ButtonHandler(QObject* parent)
 
 void ButtonHandler::hide()
 {
-    for (CaptureToolButton* b : m_vectorButtons)
+    for (CaptureToolButton* b : m_vectorButtons) {
         b->hide();
+    }
 }
 
 void ButtonHandler::show()
@@ -49,8 +35,9 @@ void ButtonHandler::show()
     if (m_vectorButtons.isEmpty() || m_vectorButtons.first()->isVisible()) {
         return;
     }
-    for (CaptureToolButton* b : m_vectorButtons)
+    for (CaptureToolButton* b : m_vectorButtons) {
         b->animatedShow();
+    }
 }
 
 bool ButtonHandler::isVisible() const
@@ -120,7 +107,7 @@ void ButtonHandler::updatePosition(const QRect& selection)
         elemsAtCorners -= elemCornersTop;
         int elemCornersBotton = qBound(0, elemsAtCorners, maxExtra);
 
-        // Add buttons at the button of the seletion
+        // Add buttons at the button of the selection
         if (!m_blockedBotton) {
             int addCounter = buttonsPerRow + elemCornersBotton;
             // Don't add more than we have
@@ -135,7 +122,7 @@ void ButtonHandler::updatePosition(const QRect& selection)
               horizontalPoints(center, addCounter, true);
             moveButtonsToPoints(positions, elemIndicator);
         }
-        // Add buttons at the right side of the seletion
+        // Add buttons at the right side of the selection
         if (!m_blockedRight && elemIndicator < vecLength) {
             int addCounter = buttonsPerCol;
             addCounter = qBound(0, addCounter, vecLength - elemIndicator);
@@ -146,7 +133,7 @@ void ButtonHandler::updatePosition(const QRect& selection)
               verticalPoints(center, addCounter, false);
             moveButtonsToPoints(positions, elemIndicator);
         }
-        // Add buttons at the top of the seletion
+        // Add buttons at the top of the selection
         if (!m_blockedTop && elemIndicator < vecLength) {
             int addCounter = buttonsPerRow + elemCornersTop;
             addCounter = qBound(0, addCounter, vecLength - elemIndicator);
@@ -159,7 +146,7 @@ void ButtonHandler::updatePosition(const QRect& selection)
               horizontalPoints(center, addCounter, false);
             moveButtonsToPoints(positions, elemIndicator);
         }
-        // Add buttons at the left side of the seletion
+        // Add buttons at the left side of the selection
         if (!m_blockedLeft && elemIndicator < vecLength) {
             int addCounter = buttonsPerCol;
             addCounter = qBound(0, addCounter, vecLength - elemIndicator);
@@ -179,6 +166,21 @@ void ButtonHandler::updatePosition(const QRect& selection)
     }
 }
 
+int ButtonHandler::calculateShift(int elements, bool reverse) const
+{
+    int shift = 0;
+    if (elements % 2 == 0) {
+        shift = m_buttonExtendedSize * (elements / 2) - (m_separator / 2);
+    } else {
+        shift =
+          m_buttonExtendedSize * ((elements - 1) / 2) + m_buttonBaseSize / 2;
+    }
+    if (!reverse) {
+        shift -= m_buttonBaseSize;
+    }
+
+    return shift;
+}
 // horizontalPoints is an auxiliary method for the button position computation.
 // starts from a known center and keeps adding elements horizontally
 // and returns the computed positions.
@@ -188,16 +190,8 @@ QVector<QPoint> ButtonHandler::horizontalPoints(const QPoint& center,
 {
     QVector<QPoint> res;
     // Distance from the center to start adding buttons
-    int shift = 0;
-    if (elements % 2 == 0) {
-        shift = m_buttonExtendedSize * (elements / 2) - (m_separator / 2);
-    } else {
-        shift =
-          m_buttonExtendedSize * ((elements - 1) / 2) + m_buttonBaseSize / 2;
-    }
-    if (!leftToRight) {
-        shift -= m_buttonBaseSize;
-    }
+    int shift = calculateShift(elements, leftToRight);
+
     int x = leftToRight ? center.x() - shift : center.x() + shift;
     QPoint i(x, center.y());
     while (elements > res.length()) {
@@ -217,16 +211,8 @@ QVector<QPoint> ButtonHandler::verticalPoints(const QPoint& center,
 {
     QVector<QPoint> res;
     // Distance from the center to start adding buttons
-    int shift = 0;
-    if (elements % 2 == 0) {
-        shift = m_buttonExtendedSize * (elements / 2) - (m_separator / 2);
-    } else {
-        shift =
-          m_buttonExtendedSize * ((elements - 1) / 2) + m_buttonBaseSize / 2;
-    }
-    if (!upToDown) {
-        shift -= m_buttonBaseSize;
-    }
+    int shift = calculateShift(elements, upToDown);
+
     int y = upToDown ? center.y() - shift : center.y() + shift;
     QPoint i(center.x(), y);
     while (elements > res.length()) {
@@ -261,27 +247,32 @@ void ButtonHandler::resetRegionTrack()
 
 void ButtonHandler::updateBlockedSides()
 {
+    QRegion screenRegion{};
+    for (const QRect& rect : m_screenRegions) {
+        screenRegion += rect;
+    }
+
     const int EXTENSION = m_separator * 2 + m_buttonBaseSize;
     // Right
     QPoint pointA(m_selection.right() + EXTENSION, m_selection.bottom());
     QPoint pointB(pointA.x(), m_selection.top());
     m_blockedRight =
-      !(m_screenRegions.contains(pointA) && m_screenRegions.contains(pointB));
+      !(screenRegion.contains(pointA) && screenRegion.contains(pointB));
     // Left
     pointA.setX(m_selection.left() - EXTENSION);
     pointB.setX(pointA.x());
     m_blockedLeft =
-      !(m_screenRegions.contains(pointA) && m_screenRegions.contains(pointB));
+      !(screenRegion.contains(pointA) && screenRegion.contains(pointB));
     // Bottom
     pointA = QPoint(m_selection.left(), m_selection.bottom() + EXTENSION);
     pointB = QPoint(m_selection.right(), pointA.y());
     m_blockedBotton =
-      !(m_screenRegions.contains(pointA) && m_screenRegions.contains(pointB));
+      !(screenRegion.contains(pointA) && screenRegion.contains(pointB));
     // Top
     pointA.setY(m_selection.top() - EXTENSION);
     pointB.setY(pointA.y());
     m_blockedTop =
-      !(m_screenRegions.contains(pointA) && m_screenRegions.contains(pointB));
+      !(screenRegion.contains(pointA) && screenRegion.contains(pointB));
     // Auxiliary
     m_oneHorizontalBlocked =
       (!m_blockedRight && m_blockedLeft) || (m_blockedRight && !m_blockedLeft);
@@ -346,7 +337,7 @@ void ButtonHandler::moveButtonsToPoints(const QVector<QPoint>& points,
                                         int& index)
 {
     for (const QPoint& p : points) {
-        auto button = m_vectorButtons[index];
+        auto* button = m_vectorButtons[index];
         button->move(p);
         ++index;
     }
@@ -362,13 +353,15 @@ void ButtonHandler::adjustHorizontalCenter(QPoint& center)
 }
 
 // setButtons redefines the buttons of the button handler
-void ButtonHandler::setButtons(const QVector<CaptureToolButton*> v)
+void ButtonHandler::setButtons(const QVector<CaptureToolButton*>& v)
 {
-    if (v.isEmpty())
+    if (v.isEmpty()) {
         return;
+    }
 
-    for (CaptureToolButton* b : m_vectorButtons)
+    for (CaptureToolButton* b : m_vectorButtons) {
         delete (b);
+    }
     m_vectorButtons = v;
     m_buttonBaseSize = GlobalValues::buttonBaseSize();
     m_buttonExtendedSize = m_buttonBaseSize + m_separator;
@@ -376,6 +369,9 @@ void ButtonHandler::setButtons(const QVector<CaptureToolButton*> v)
 
 bool ButtonHandler::contains(const QPoint& p) const
 {
+    if (m_vectorButtons.isEmpty()) {
+        return false;
+    }
     QPoint first(m_vectorButtons.first()->pos());
     QPoint last(m_vectorButtons.last()->pos());
     bool firstIsTopLeft = (first.x() <= last.x() && first.y() <= last.y());
@@ -389,13 +385,10 @@ bool ButtonHandler::contains(const QPoint& p) const
 
 void ButtonHandler::updateScreenRegions(const QVector<QRect>& rects)
 {
-    m_screenRegions = QRegion();
-    for (const QRect& rect : rects) {
-        m_screenRegions += rect;
-    }
+    m_screenRegions = rects;
 }
 
 void ButtonHandler::updateScreenRegions(const QRect& rect)
 {
-    m_screenRegions = QRegion(rect);
+    m_screenRegions = { rect };
 }
