@@ -155,7 +155,11 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
 #if !defined(FLAMESHOT_DEBUG_CAPTURE)
         setWindowFlags(Qt::BypassWindowManagerHint | Qt::WindowStaysOnTopHint |
                        Qt::FramelessWindowHint | Qt::Tool);
-        resize(pixmap().size());
+        // Fix for Qt6 dual monitor offset: position widget to cover entire
+        // desktop
+        QRect desktopGeom = ScreenGrabber().desktopGeometry();
+        move(desktopGeom.topLeft());
+        resize(desktopGeom.size());
 #endif
 #endif
     }
