@@ -14,12 +14,15 @@
 #include "buttonhandler.h"
 #include "capturetoolbutton.h"
 #include "capturetoolobjects.h"
+#include "src/config/generalconf.h"
 #include "src/tools/capturecontext.h"
 #include "src/tools/capturetool.h"
 #include "src/utils/confighandler.h"
 #include "src/widgets/capture/magnifierwidget.h"
 #include "src/widgets/capture/selectionwidget.h"
+#include <QMessageBox>
 #include <QPointer>
+#include <QTimer>
 #include <QUndoStack>
 #include <QWidget>
 
@@ -33,7 +36,9 @@ class QNetworkReply;
 class ColorPicker;
 class NotifierBox;
 class HoverEventFilter;
+#if !defined(DISABLE_UPDATE_CHECKER)
 class UpdateNotificationWidget;
+#endif
 class UtilityPanel;
 class SidePanelWidget;
 
@@ -48,9 +53,11 @@ public:
     ~CaptureWidget();
 
     QPixmap pixmap();
+    void setCaptureToolObjects(const CaptureToolObjects& captureToolObjects);
+#if !defined(DISABLE_UPDATE_CHECKER)
     void showAppUpdateNotification(const QString& appLatestVersion,
                                    const QString& appLatestUrl);
-    void setCaptureToolObjects(const CaptureToolObjects& captureToolObjects);
+#endif
 
 public slots:
     bool commitCurrentTool();
@@ -63,6 +70,7 @@ signals:
 private slots:
     void undo();
     void redo();
+    void cancel();
     void togglePanel();
     void childEnter();
     void childLeave();
@@ -80,9 +88,13 @@ private slots:
     void onMoveCaptureToolUp(int captureToolIndex);
     void onMoveCaptureToolDown(int captureToolIndex);
     void selectAll();
+    void xywhTick();
+    void onDisplayGridChanged(bool display);
+    void onGridSizeChanged(int size);
 
 public:
     void removeToolObject(int index = -1);
+    void showxywh();
 
 protected:
     void paintEvent(QPaintEvent* paintEvent) override;
@@ -111,11 +123,13 @@ private:
     void initShortcuts();
     void initButtons();
     void initHelpMessage();
+    void initQuitPrompt();
     void updateSizeIndicator();
     void updateCursor();
     void updateSelectionState();
     void updateTool(CaptureTool* tool);
     void updateLayersPanel();
+    bool promptQuit();
     void pushToolToStack();
     void makeChild(QWidget* w);
     void restoreCircleCountState();
@@ -139,6 +153,8 @@ private:
     CaptureTool* activeButtonTool() const;
     CaptureTool::Type activeButtonToolType() const;
 
+    QPoint snapToGrid(const QPoint& point) const;
+
     ////////////////////////////////////////
     // Class members
 
@@ -164,7 +180,9 @@ private:
     bool m_configError;
     bool m_configErrorResolved;
 
+#if !defined(DISABLE_UPDATE_CHECKER)
     UpdateNotificationWidget* m_updateNotificationWidget;
+#endif
     quint64 m_lastMouseWheel;
     QPointer<CaptureToolButton> m_sizeIndButton;
     // Last pressed button
@@ -172,6 +190,7 @@ private:
     QPointer<CaptureTool> m_activeTool;
     bool m_activeToolIsMoved;
     QPointer<QWidget> m_toolWidget;
+    QPointer<QMessageBox> m_quitPrompt;
 
     ButtonHandler* m_buttonHandler;
     UtilityPanel* m_panel;
@@ -193,6 +212,10 @@ private:
     QPoint m_mousePressedPos;
     QPoint m_activeToolOffsetToMouseOnStart;
 
+    // XYWH display position and timer
+    bool m_xywhDisplay;
+    QTimer m_xywhTimer;
+
     QUndoStack m_undoStack;
 
     bool m_existingObjectIsChanged;
@@ -200,4 +223,8 @@ private:
     // For start moving after more than X offset
     QPoint m_startMovePos;
     bool m_startMove;
+
+    // Grid
+    bool m_displayGrid{ false };
+    int m_gridSize{ 10 };
 };
