@@ -1,24 +1,9 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 // Based on https://stackoverflow.com/a/53135675/964478
 
 #include "orientablepushbutton.h"
-#include <QDebug>
 #include <QPainter>
 #include <QStyleOptionButton>
 #include <QStylePainter>
@@ -77,7 +62,7 @@ OrientablePushButton::Orientation OrientablePushButton::orientation() const
 }
 
 void OrientablePushButton::setOrientation(
-  const OrientablePushButton::Orientation& orientation)
+  OrientablePushButton::Orientation orientation)
 {
     m_orientation = orientation;
 }
